pub struct Harness { /* private fields */ }Expand description
Runs sweeps against a dataset using a fixed embedder (+ optional LLM).
Implementations
Sourceimpl Harness
impl Harness
Sourcepub fn new(
embedder: Arc<dyn Embedder>,
chat: Option<Arc<dyn ChatModel>>,
) -> Self
pub fn new( embedder: Arc<dyn Embedder>, chat: Option<Arc<dyn ChatModel>>, ) -> Self
Build a harness with the embedder used for every config in the sweep.
Sourcepub async fn run(
&self,
dataset: &EvalDataset,
chunk_configs: &[(usize, f32)],
modes: &[RetrievalMode],
top_k: usize,
) -> Result<EvalReport>
pub async fn run( &self, dataset: &EvalDataset, chunk_configs: &[(usize, f32)], modes: &[RetrievalMode], top_k: usize, ) -> Result<EvalReport>
Run the sweep. modes that need an LLM are skipped when no ChatModel
was provided.